@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -135,8 +136,6 @@ USHORT SwDoc::GetTOIKeys( SwTOIKeyType eTyp, SvStringsSort& rArr ) const
 /*--------------------------------------------------------------------
      Beschreibung: aktuelle Verzeichnismarkierungen ermitteln
  --------------------------------------------------------------------*/
-
-
 USHORT SwDoc::GetCurTOXMark( const SwPosition& rPos,
                                 SwTOXMarks& rArr ) const
 {
@@ -178,15 +177,14 @@ USHORT SwDoc::GetCurTOXMark( const SwPosition& rPos,
 /*--------------------------------------------------------------------
      Beschreibung: Marke loeschen
  --------------------------------------------------------------------*/
-
 void SwDoc::DeleteTOXMark( const SwTOXMark* pTOXMark )
 {
     // hole den TextNode und
     const SwTxtTOXMark* pTxtTOXMark = pTOXMark->GetTxtTOXMark();
-    ASSERT( pTxtTOXMark, "Kein TxtTOXMark, kann nicht geloescht werden" );
+    OSL_ENSURE( pTxtTOXMark, "Kein TxtTOXMark, kann nicht geloescht werden" );
 
     SwTxtNode& rTxtNd = const_cast<SwTxtNode&>(pTxtTOXMark->GetTxtNode());
-    ASSERT( rTxtNd.GetpSwpHints(), "kann nicht geloescht werden" );
+    OSL_ENSURE( rTxtNd.GetpSwpHints(), "kann nicht geloescht werden" );
 
     if( DoesUndo() )
     {
@@ -214,7 +212,6 @@ void SwDoc::DeleteTOXMark( const SwTOXMark* pTOXMark )
 /*--------------------------------------------------------------------
      Beschreibung: Traveln zwischen TOXMarks
  --------------------------------------------------------------------*/
-
 class CompareNodeCntnt
 {
     ULONG nNode;
@@ -245,7 +242,7 @@ const SwTOXMark& SwDoc::GotoTOXMark( const SwTOXMark& rCurTOXMark,
                                     SwTOXSearch eDir, BOOL bInReadOnly )
 {
     const SwTxtTOXMark* pMark = rCurTOXMark.GetTxtTOXMark();
-    ASSERT(pMark, "pMark==0 Ungueltige TxtTOXMark");
+    OSL_ENSURE(pMark, "pMark==0 Ungueltige TxtTOXMark");
 
     const SwTxtNode *pTOXSrc = pMark->GetpTxtNd();
 
@@ -357,8 +354,6 @@ const SwTOXMark& SwDoc::GotoTOXMark( const SwTOXMark& rCurTOXMark,
     return *pNew;
 }
 
-/*  */
-
 const SwTOXBaseSection* SwDoc::InsertTableOf( const SwPosition& rPos,
                                                 const SwTOXBase& rTOX,
                                                 const SfxItemSet* pSet,
@@ -411,8 +406,6 @@ sNm.AppendAscii( RTL_CONSTASCII_STRINGPARAM( "_Head" ));
     return pNewSection;
 }
 
-
-
 const SwTOXBaseSection* SwDoc::InsertTableOf( ULONG nSttNd, ULONG nEndNd,
                                                 const SwTOXBase& rTOX,
                                                 const SfxItemSet* pSet )
@@ -457,7 +450,6 @@ const SwTOXBaseSection* SwDoc::InsertTableOf( ULONG nSttNd, ULONG nEndNd,
 /*--------------------------------------------------------------------
      Beschreibung: Aktuelles Verzeichnis ermitteln
  --------------------------------------------------------------------*/
-
 const SwTOXBase* SwDoc::GetCurTOX( const SwPosition& rPos ) const
 {
     const SwNode& rNd = rPos.nNode.GetNode();
@@ -467,7 +459,7 @@ const SwTOXBase* SwDoc::GetCurTOX( const SwPosition& rPos ) const
         SectionType eT = pSectNd->GetSection().GetType();
         if( TOX_CONTENT_SECTION == eT )
         {
-            ASSERT( pSectNd->GetSection().ISA( SwTOXBaseSection ),
+            OSL_ENSURE( pSectNd->GetSection().ISA( SwTOXBaseSection ),
                     "keine TOXBaseSection!" );
             SwTOXBaseSection& rTOXSect = (SwTOXBaseSection&)
                                                 pSectNd->GetSection();
@@ -477,20 +469,16 @@ const SwTOXBase* SwDoc::GetCurTOX( const SwPosition& rPos ) const
     }
     return 0;
 }
-/* -----------------01.09.99 16:01-------------------
 
- --------------------------------------------------*/
 const SwAttrSet& SwDoc::GetTOXBaseAttrSet(const SwTOXBase& rTOXBase) const
 {
-    ASSERT( rTOXBase.ISA( SwTOXBaseSection ), "no TOXBaseSection!" );
+    OSL_ENSURE( rTOXBase.ISA( SwTOXBaseSection ), "no TOXBaseSection!" );
     const SwTOXBaseSection& rTOXSect = (const SwTOXBaseSection&)rTOXBase;
     SwSectionFmt* pFmt = rTOXSect.GetFmt();
-    ASSERT( pFmt, "invalid TOXBaseSection!" );
+    OSL_ENSURE( pFmt, "invalid TOXBaseSection!" );
     return pFmt->GetAttrSet();
 }
-/* -----------------02.09.99 07:48-------------------
 
- --------------------------------------------------*/
 const SwTOXBase* SwDoc::GetDefaultTOXBase( TOXTypes eTyp, BOOL bCreate )
 {
     SwTOXBase** prBase = 0;
@@ -512,9 +500,7 @@ const SwTOXBase* SwDoc::GetDefaultTOXBase( TOXTypes eTyp, BOOL bCreate )
     }
     return (*prBase);
 }
-/* -----------------02.09.99 08:06-------------------
 
- --------------------------------------------------*/
 void	SwDoc::SetDefaultTOXBase(const SwTOXBase& rBase)
 {
     SwTOXBase** prBase = 0;
@@ -536,13 +522,11 @@ void	SwDoc::SetDefaultTOXBase(const SwTOXBase& rBase)
 /*--------------------------------------------------------------------
      Beschreibung: Verzeichnis loeschen
  --------------------------------------------------------------------*/
-
-
 BOOL SwDoc::DeleteTOX( const SwTOXBase& rTOXBase, BOOL bDelNodes )
 {
     // its only delete the TOX, not the nodes
     BOOL bRet = FALSE;
-    ASSERT( rTOXBase.ISA( SwTOXBaseSection ), "keine TOXBaseSection!" );
+    OSL_ENSURE( rTOXBase.ISA( SwTOXBaseSection ), "keine TOXBaseSection!" );
 
     const SwTOXBaseSection& rTOXSect = (const SwTOXBaseSection&)rTOXBase;
     SwSectionFmt* pFmt = rTOXSect.GetFmt();
@@ -630,7 +614,6 @@ BOOL SwDoc::DeleteTOX( const SwTOXBase& rTOXBase, BOOL bDelNodes )
 /*--------------------------------------------------------------------
      Beschreibung:	Verzeichnistypen verwalten
  --------------------------------------------------------------------*/
-
 USHORT SwDoc::GetTOXTypeCount(TOXTypes eTyp) const
 {
     const SwTOXTypePtr * ppTTypes = pTOXTypes->GetData();
@@ -640,9 +623,7 @@ USHORT SwDoc::GetTOXTypeCount(TOXTypes eTyp) const
             ++nCnt;
     return nCnt;
 }
-/*--------------------------------------------------------------------
 
- --------------------------------------------------------------------*/
 const SwTOXType* SwDoc::GetTOXType( TOXTypes eTyp, USHORT nId ) const
 {
     const SwTOXTypePtr * ppTTypes = pTOXTypes->GetData();
@@ -653,18 +634,13 @@ const SwTOXType* SwDoc::GetTOXType( TOXTypes eTyp, USHORT nId ) const
     return 0;
 }
 
-/*--------------------------------------------------------------------
-
- --------------------------------------------------------------------*/
 const SwTOXType* SwDoc::InsertTOXType( const SwTOXType& rTyp )
 {
     SwTOXType * pNew = new SwTOXType( rTyp );
     pTOXTypes->Insert( pNew, pTOXTypes->Count() );
     return pNew;
 }
-/*--------------------------------------------------------------------
 
- --------------------------------------------------------------------*/
 String SwDoc::GetUniqueTOXBaseName( const SwTOXType& rType,
                                     const String* pChkStr ) const
 {
@@ -719,12 +695,9 @@ String SwDoc::GetUniqueTOXBaseName( const SwTOXType& rType,
     return aName += String::CreateFromInt32( ++nNum );
 }
 
-/*--------------------------------------------------------------------
-
- --------------------------------------------------------------------*/
 BOOL SwDoc::SetTOXBaseName(const SwTOXBase& rTOXBase, const String& rName)
 {
-    ASSERT( rTOXBase.ISA( SwTOXBaseSection ),
+    OSL_ENSURE( rTOXBase.ISA( SwTOXBaseSection ),
                     "keine TOXBaseSection!" );
     SwTOXBaseSection* pTOX = (SwTOXBaseSection*)&rTOXBase;
 
@@ -739,8 +712,6 @@ BOOL SwDoc::SetTOXBaseName(const SwTOXBase& rTOXBase, const String& rName)
     return bRet;
 }
 
-/*  */
-
 const SwTxtNode* lcl_FindChapterNode( const SwNode& rNd, BYTE nLvl = 0 )
 {
     const SwNode* pNd = &rNd;
@@ -755,17 +726,15 @@ const SwTxtNode* lcl_FindChapterNode( const SwNode& rNd, BYTE nLvl = 0 )
         {
             SwPosition aPos( *pNd );
             pNd = GetBodyTxtNode( *pNd->GetDoc(), aPos, *pFrm );
-            ASSERT( pNd,	"wo steht der Absatz" );
+            OSL_ENSURE( pNd,	"wo steht der Absatz" );
         }
     }
     return pNd ? pNd->FindOutlineNodeOfLevel( nLvl ) : 0;
 }
 
-
 /*--------------------------------------------------------------------
      Beschreibung: Verzeichnis-Klasse
  --------------------------------------------------------------------*/
-
 SwTOXBaseSection::SwTOXBaseSection(SwTOXBase const& rBase, SwSectionFmt & rFmt)
     : SwTOXBase( rBase )
     , SwSection( TOX_CONTENT_SECTION, aEmptyStr, rFmt )
@@ -774,12 +743,10 @@ SwTOXBaseSection::SwTOXBaseSection(SwTOXBase const& rBase, SwSectionFmt & rFmt)
     SetSectionName( GetTOXName() );
 }
 
-
 SwTOXBaseSection::~SwTOXBaseSection()
 {
 }
 
-
 BOOL SwTOXBaseSection::SetPosAtStartEnd( SwPosition& rPos, BOOL bAtStart ) const
 {
     BOOL bRet = FALSE;
@@ -808,7 +775,6 @@ BOOL SwTOXBaseSection::SetPosAtStartEnd( SwPosition& rPos, BOOL bAtStart ) const
 /*--------------------------------------------------------------------
      Beschreibung: Verzeichnisinhalt zusammensammeln
  --------------------------------------------------------------------*/
-
 void SwTOXBaseSection::Update(const SfxItemSet* pAttr,
                               const bool        _bNewTOX )
 {
@@ -1099,8 +1065,6 @@ sNm.AppendAscii( RTL_CONSTASCII_STRINGPARAM( "_Head" ));
 /*--------------------------------------------------------------------
      Beschreibung: AlphaDelimitter einfuegen
  --------------------------------------------------------------------*/
-
-
 void SwTOXBaseSection::InsertAlphaDelimitter( const SwTOXInternational& rIntl )
 {
     SwDoc* pDoc = (SwDoc*)GetFmt()->GetDoc();
@@ -1145,7 +1109,6 @@ void SwTOXBaseSection::InsertAlphaDelimitter( const SwTOXInternational& rIntl )
 /*--------------------------------------------------------------------
      Beschreibung: Template  auswerten
  --------------------------------------------------------------------*/
-
 SwTxtFmtColl* SwTOXBaseSection::GetTxtFmtColl( USHORT nLevel )
 {
     SwDoc* pDoc = (SwDoc*)GetFmt()->GetDoc();
@@ -1193,11 +1156,9 @@ SwTxtFmtColl* SwTOXBaseSection::GetTxtFmtColl( USHORT nLevel )
     return pColl;
 }
 
-
 /*--------------------------------------------------------------------
      Beschreibung: Aus Markierungen erzeugen
  --------------------------------------------------------------------*/
-
 void SwTOXBaseSection::UpdateMarks( const SwTOXInternational& rIntl,
                                     const SwTxtNode* pOwnChapterNode )
 {
@@ -1271,12 +1232,9 @@ void SwTOXBaseSection::UpdateMarks( const SwTOXInternational& rIntl,
     }
 }
 
-
 /*--------------------------------------------------------------------
      Beschreibung:	Verzeichnisinhalt aus Gliederungsebene generieren
  --------------------------------------------------------------------*/
-
-
 void SwTOXBaseSection::UpdateOutline( const SwTxtNode* pOwnChapterNode )
 {
     SwDoc* pDoc = (SwDoc*)GetFmt()->GetDoc();
@@ -1305,7 +1263,6 @@ void SwTOXBaseSection::UpdateOutline( const SwTxtNode* pOwnChapterNode )
 /*--------------------------------------------------------------------
      Beschreibung: Verzeichnisinhalt aus Vorlagenbereichen generieren
  --------------------------------------------------------------------*/
-
 void SwTOXBaseSection::UpdateTemplate( const SwTxtNode* pOwnChapterNode )
 {
     SwDoc* pDoc = (SwDoc*)GetFmt()->GetDoc();
@@ -1385,9 +1342,7 @@ void SwTOXBaseSection::UpdateSequence( const SwTxtNode* pOwnChapterNode )
         }
     }
 }
-/* -----------------15.09.99 14:18-------------------
 
- --------------------------------------------------*/
 void SwTOXBaseSection::UpdateAuthorities( const SwTOXInternational& rIntl )
 {
     SwDoc* pDoc = (SwDoc*)GetFmt()->GetDoc();
@@ -1580,7 +1535,6 @@ void SwTOXBaseSection::UpdateCntnt( SwTOXElement eMyType,
 /*--------------------------------------------------------------------
      Beschreibung:	Tabelleneintraege zusammensuchen
  --------------------------------------------------------------------*/
-
 void SwTOXBaseSection::UpdateTable( const SwTxtNode* pOwnChapterNode )
 {
     SwDoc* pDoc = (SwDoc*)GetFmt()->GetDoc();
@@ -1635,7 +1589,6 @@ void SwTOXBaseSection::UpdateTable( const SwTxtNode* pOwnChapterNode )
      Beschreibung:	String generieren anhand der Form
                     SonderZeichen 0-31 und 255 entfernen
  --------------------------------------------------------------------*/
-
 String lcl_GetNumString( const SwTOXSortTabBase& rBase, sal_Bool bUsePrefix, BYTE nLevel )
 {
     String sRet;
@@ -1677,7 +1630,7 @@ void SwTOXBaseSection::GenerateText( USHORT nArrayIdx,
         // String mit dem Pattern aus der Form initialisieren
         const SwTOXSortTabBase& rBase = *aSortArr[nIndex];
         USHORT nLvl = rBase.GetLevel();
-        ASSERT( nLvl < GetTOXForm().GetFormMax(), "ungueltiges FORM_LEVEL");
+        OSL_ENSURE( nLvl < GetTOXForm().GetFormMax(), "ungueltiges FORM_LEVEL");
 
         SvxTabStopItem aTStops( 0, 0, SVX_TAB_ADJUST_DEFAULT, RES_PARATR_TABSTOP );
         xub_StrLen nLinkStartPosition = STRING_NOTFOUND;
@@ -1957,7 +1910,6 @@ void SwTOXBaseSection::GenerateText( USHORT nArrayIdx,
      Beschreibung: Seitennummer errechnen und nach dem Formatieren
                    eintragen
  --------------------------------------------------------------------*/
-
 void SwTOXBaseSection::UpdatePageNum()
 {
     if( !aSortArr.Count() )
@@ -2012,7 +1964,7 @@ void SwTOXBaseSection::UpdatePageNum()
                 if( rTOXSource.pNd )
                 {
                     SwCntntFrm* pFrm = rTOXSource.pNd->GetFrm();
-                    ASSERT( pFrm || pDoc->IsUpdateTOX(), "TOX, no Frame found");
+                    OSL_ENSURE( pFrm || pDoc->IsUpdateTOX(), "TOX, no Frame found");
                     if( !pFrm )
                         continue;
                     if( pFrm->IsTxtFrm() && ((SwTxtFrm*)pFrm)->HasFollow() )
@@ -2055,7 +2007,7 @@ void SwTOXBaseSection::UpdatePageNum()
             if(pBase->pTOXNd)
             {
                 const SwTxtNode* pTxtNd = pBase->pTOXNd->GetTxtNode();
-                ASSERT( pTxtNd, "kein TextNode, falsches Verzeichnis" );
+                OSL_ENSURE( pTxtNd, "kein TextNode, falsches Verzeichnis" );
 
                 _UpdatePageNum( (SwTxtNode*)pTxtNd, aNums, aDescs, pMainNums,
                                 aIntl );
@@ -2069,11 +2021,9 @@ void SwTOXBaseSection::UpdatePageNum()
     aSortArr.DeleteAndDestroy( 0, aSortArr.Count() );
 }
 
-
 /*--------------------------------------------------------------------
      Beschreibung: Austausch der Seitennummer-Platzhalter
  --------------------------------------------------------------------*/
-
 // search for the page no in the array of main entry page numbers
 BOOL lcl_HasMainEntry( const SvUShorts* pMainEntryNums, USHORT nToFind )
 {
@@ -2249,11 +2199,9 @@ void SwTOXBaseSection::_UpdatePageNum( SwTxtNode* pNd,
     delete pCharStyleIdx;
 }
 
-
 /*--------------------------------------------------------------------
      Beschreibung: Sortiert einfuegen in das SortArr
  --------------------------------------------------------------------*/
-
 void SwTOXBaseSection::InsertSorted(SwTOXSortTabBase* pNew)
 {
     Range aRange(0, aSortArr.Count());
@@ -2329,7 +2277,7 @@ void SwTOXBaseSection::InsertSorted(SwTOXSortTabBase* pNew)
                 delete pNew;
                 return;
             }
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
             else
                 DBG_ERROR("Bibliography entries cannot be found here");
 #endif
@@ -2349,7 +2297,6 @@ void SwTOXBaseSection::InsertSorted(SwTOXSortTabBase* pNew)
 /*--------------------------------------------------------------------
      Beschreibung: Schluessel-Bereich suchen und evtl einfuegen
  --------------------------------------------------------------------*/
-
 Range SwTOXBaseSection::GetKeyRange(const String& rStr, const String& rStrReading,
                                     const SwTOXSortTabBase& rNew,
                                     USHORT nLevel, const Range& rRange )
@@ -2364,7 +2311,7 @@ Range SwTOXBaseSection::GetKeyRange(const String& rStr, const String& rStrReadin
         sToCompare.Erase( 0, 1 ).Insert( sUpper, 0 );
     }
 
-    ASSERT(rRange.Min() >= 0 && rRange.Max() >= 0, "Min Max < 0");
+    OSL_ENSURE(rRange.Min() >= 0 && rRange.Max() >= 0, "Min Max < 0");
 
     const USHORT nMin = (USHORT)rRange.Min();
     const USHORT nMax = (USHORT)rRange.Max();
@@ -2410,7 +2357,6 @@ Range SwTOXBaseSection::GetKeyRange(const String& rStr, const String& rStrReadin
     return Range(nStart, nEnd);
 }
 
-
 BOOL SwTOXBase::IsTOXBaseInReadonly() const
 {
     const SwTOXBaseSection *pSect = PTR_CAST(SwTOXBaseSection, this);
@@ -2428,9 +2374,7 @@ BOOL SwTOXBase::IsTOXBaseInReadonly() const
     }
     return bRet;
 }
-/* -----------------17.08.99 13:29-------------------
 
- --------------------------------------------------*/
 const SfxItemSet* SwTOXBase::GetAttrSet() const
 {
     const SwTOXBaseSection *pSect = PTR_CAST(SwTOXBaseSection, this);
@@ -2461,6 +2405,4 @@ BOOL SwTOXBase::GetInfo( SfxPoolItem& rInfo ) const
     return TRUE;
 }
 
-/*  */
-
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
