@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,9 +33,7 @@
 #include <sfx2/docfilt.hxx>
 #include <sot/storage.hxx>
 #include <tools/urlobj.hxx>
-#ifndef SVTOOLS_FSTATHELPER_HXX
 #include <svl/fstathelper.hxx>
-#endif
 #include <svl/macitem.hxx>
 #include <unotools/charclass.hxx>
 #include <frmfmt.hxx>
@@ -46,14 +45,10 @@
 #include <ndtxt.hxx>
 #include <mdiexp.hxx>		// Progress
 #include <SwXMLTextBlocks.hxx>
-#ifndef _DOCSH_HXX
 #include <docsh.hxx>
-#endif
 #include <swunohelper.hxx>
 
-#ifndef _STATSTR_HRC
 #include <statstr.hrc>
-#endif
 #include <swerror.h>
 
 SV_IMPL_OP_PTRARR_SORT( SwBlockNames, SwBlockName* );
@@ -527,7 +522,7 @@ USHORT SwTextBlocks::Rename( USHORT n, const String* s, const String* l )
             aLong = *l;
         if( !aNew.Len() )
         {
-            ASSERT( !this, "Kein Kurzname in Rename angegeben" );
+            OSL_ENSURE( !this, "Kein Kurzname in Rename angegeben" );
             nErr = ERR_SWG_INTERNAL_ERROR; return (USHORT) -1;
         }
 
@@ -761,7 +756,7 @@ BOOL SwTextBlocks::IsOnlyTextBlock( const String& rShort ) const
         return IsOnlyTextBlock( nIdx );
     }
 
-    ASSERT( !this, "ungueltiger Name" );
+    OSL_ENSURE( !this, "ungueltiger Name" );
     return FALSE;
 }
 
@@ -816,3 +811,4 @@ void SwTextBlocks::SetBaseURL( const String& rURL )
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
