@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -560,7 +561,7 @@ void SwWrongList::Remove(USHORT nIdx, USHORT nLen )
     maList.erase(i1, i2);
 
 #if OSL_DEBUG_LEVEL > 1
-    ASSERT( Count() + nLen == nOldSize, "SwWrongList::Remove() trouble" )
+    OSL_ENSURE( Count() + nLen == nOldSize, "SwWrongList::Remove() trouble" );
 #endif
 }
 
@@ -642,3 +643,4 @@ void SwWrongList::Insert( const rtl::OUString& rType,
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
