@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -53,9 +54,7 @@
 #include "fmtornt.hxx"
 #include "fmtfsize.hxx"
 
-#ifndef _FMTLSPLT_HXX
 #include "fmtlsplt.hxx"
-#endif
 #include <xmloff/prhdlfac.hxx>
 #include <xmloff/xmltypes.hxx>
 #include "xmlithlp.hxx"
@@ -288,7 +287,7 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
 
                 case MID_FIRST_AUTO:
                 {
-                    sal_Bool bAutoFirst;
+                    bool bAutoFirst;
                     bOk = rUnitConverter.convertBool( bAutoFirst, rValue );
                     if( bOk )
                         pLRSpace->SetAutoFirst( bAutoFirst );
@@ -974,3 +973,4 @@ sal_Bool SvXMLImportItemMapper::PutXMLValue(
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
