@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -238,9 +239,13 @@ SwReadOnlyPopup::SwReadOnlyPopup( const Point &rDPos, SwView &rV ) :
         EnableItem( MN_READONLY_COPY, FALSE );
 
     eState = pVFrame->GetBindings().QueryState( SID_EDITDOC, pState );
-    if(eState < SFX_ITEM_DEFAULT ||
-        rSh.IsGlobalDoc() && rView.GetDocShell()->IsReadOnlyUI())
+    if (
+        eState < SFX_ITEM_DEFAULT ||
+        (rSh.IsGlobalDoc() && rView.GetDocShell()->IsReadOnlyUI())
+       )
+    {
         EnableItem( MN_READONLY_EDITDOC, FALSE );
+    }
 
     if ( !sURL.Len() )
     {
@@ -517,3 +522,4 @@ String ExportGraphic( const Graphic &rGraphic, const String &rGrfName )
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
