@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -85,8 +86,6 @@
 
 #include <dialog.hrc>
 
-
-
 //!!! new: insert table
 /*
 #include <svx/htmlmode.hxx>
@@ -96,19 +95,11 @@
 */
 //!!!
 
-#ifndef _POPUP_HRC
 #include <popup.hrc>
-#endif
-#ifndef _SHELLS_HRC
 #include <shells.hrc>
-#endif
-#ifndef _TABLE_HRC
 #include <table.hrc>
-#endif
 #include <cmdid.h>
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
 #include <helpid.h>
 #include <unobaseclass.hxx>
 
@@ -121,19 +112,14 @@
 
 using namespace ::com::sun::star;
 
-//-----------------------------------------------------------------------------
-
 SFX_IMPL_INTERFACE(SwTableShell, SwBaseShell, SW_RES(STR_SHELLNAME_TABLE))
 {
     SFX_POPUPMENU_REGISTRATION(SW_RES(MN_TAB_POPUPMENU));
     SFX_OBJECTBAR_REGISTRATION(SFX_OBJECTBAR_OBJECT, SW_RES(RID_TABLE_TOOLBOX));
 }
 
-
 TYPEINIT1(SwTableShell,SwBaseShell)
 
-/************************************************************************/
-
 const USHORT __FAR_DATA aUITableAttrRange[] =
 {
     FN_PARAM_TABLE_NAME, 			FN_PARAM_TABLE_NAME,
@@ -173,9 +159,6 @@ static void lcl_SetAttr( SwWrtShell &rSh, const SfxPoolItem &rItem )
     rSh.SetTblAttr( aSet );
 }
 
-/************************************************************************/
-
-
 static SwTableRep*  lcl_TableParamToItemSet( SfxItemSet& rSet, SwWrtShell &rSh )
 {
     SwFrmFmt *pFmt = rSh.GetTableFmt();
@@ -220,7 +203,7 @@ static SwTableRep*  lcl_TableParamToItemSet( SfxItemSet& rSet, SwWrtShell &rSh )
 
         // Tabellenvariante, wenn mehrere Tabellenzellen selektiert
     rSh.GetCrsr();					//Damit GetCrsrCnt() auch das Richtige liefert
-    aBoxInfo.SetTable          (rSh.IsTableMode() && rSh.GetCrsrCnt() > 1 ||
+    aBoxInfo.SetTable          ((rSh.IsTableMode() && rSh.GetCrsrCnt() > 1) ||
                                     !bTableSel);
         // Abstandsfeld immer anzeigen
     aBoxInfo.SetDist           ((BOOL) TRUE);
@@ -303,9 +286,6 @@ static SwTableRep*  lcl_TableParamToItemSet( SfxItemSet& rSet, SwWrtShell &rSh )
     return pRep;
 }
 
-/************************************************************************/
-
-
 void ItemSetToTableParam( const SfxItemSet& rSet,
                                 SwWrtShell &rSh )
 {
@@ -483,9 +463,6 @@ void ItemSetToTableParam( const SfxItemSet& rSet,
     rSh.EndAllAction();
 }
 
-/************************************************************************/
-
-
 static void lcl_TabGetMaxLineWidth(const SvxBorderLine* pBorderLine, SvxBorderLine& rBorderLine)
 {
     if(pBorderLine->GetInWidth() > rBorderLine.GetInWidth())
@@ -500,7 +477,6 @@ static void lcl_TabGetMaxLineWidth(const SvxBorderLine* pBorderLine, SvxBorderLi
     rBorderLine.SetColor(pBorderLine->GetColor());
 }
 
-
 void SwTableShell::Execute(SfxRequest &rReq)
 {
     BOOL bUseDialog = TRUE;
@@ -558,7 +534,7 @@ void SwTableShell::Execute(SfxRequest &rReq)
                     aBox.SetDistance( Max(rCoreBox.GetDistance(),(USHORT)MIN_BORDER_DIST)  );
             }
             else
-                {ASSERT( !this, "Wo ist das Box-Item?" )}
+                OSL_ENSURE( !this, "where is BoxItem?" );
 
             //since the drawing layer also supports borders the which id might be a different one
             SvxBoxInfoItem aInfo( SID_ATTR_BORDER_INNER );
@@ -649,10 +625,10 @@ void SwTableShell::Execute(SfxRequest &rReq)
             if ( bUseDialog )
             {
                 SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-                DBG_ASSERT(pFact, "SwAbstractDialogFactory fail!");
+                OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
 
                 pDlg = pFact->CreateSwTableTabDlg( GetView().GetWindow(), GetPool(), &aCoreSet, &rSh, DLG_FORMAT_TABLE );
-                DBG_ASSERT(pDlg, "Dialogdiet fail!");
+                OSL_ENSURE(pDlg, "Dialogdiet fail!");
             }
             aCoreSet.Put(SfxUInt16Item(SID_HTML_MODE, ::GetHtmlMode(GetView().GetDocShell())));
             rSh.GetTblAttr(aCoreSet);
@@ -663,7 +639,7 @@ void SwTableShell::Execute(SfxRequest &rReq)
             else
                 aCoreSet.InvalidateItem( RES_BACKGROUND );
 
-            if ( !pDlg && rReq.GetArgs() || pDlg->Execute() == RET_OK )
+            if ( (!pDlg && rReq.GetArgs()) || pDlg->Execute() == RET_OK )
             {
                 const SfxItemSet* pOutSet = pDlg ? pDlg->GetOutputItemSet() : rReq.GetArgs();
                 if ( pDlg )
@@ -726,12 +702,12 @@ void SwTableShell::Execute(SfxRequest &rReq)
                                     sCurText, SID_ATTR_NUMBERFORMAT_INFO ));
 
                 SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-                DBG_ASSERT(pFact, "SwAbstractDialogFactory fail!");
+                OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
 
                 SfxAbstractDialog* pDlg = pFact->CreateSfxDialog( GetView().GetWindow(),aCoreSet,
                     pView->GetViewFrame()->GetFrame().GetFrameInterface(),
                     RC_DLG_SWNUMFMTDLG );
-                DBG_ASSERT(pDlg, "Dialogdiet fail!");
+                OSL_ENSURE(pDlg, "Dialogdiet fail!");
 
                 if (RET_OK == pDlg->Execute())
                 {
@@ -821,7 +797,7 @@ void SwTableShell::Execute(SfxRequest &rReq)
                         aInfoBox.Execute();
                         break;
                     }
-                    default: ASSERT( !this, "unbekannter Returnwert MergeTab.");
+                    default: OSL_ENSURE( !this, "unknown return value MergeTab.");
                 }
         break;
         case FN_TABLE_ADJUST_CELLS:
@@ -874,10 +850,10 @@ void SwTableShell::Execute(SfxRequest &rReq)
         case SID_AUTOFORMAT:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            DBG_ASSERT(pFact, "SwAbstractDialogFactory fail!");
+            OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
 
             AbstractSwAutoFormatDlg* pDlg = pFact->CreateSwAutoFormatDlg(&GetView().GetViewFrame()->GetWindow(), &rSh , DLG_AUTOFMT_TABLE );
-            DBG_ASSERT(pDlg, "Dialogdiet fail!");
+            OSL_ENSURE(pDlg, "Dialogdiet fail!");
             pDlg->Execute();
             delete pDlg;
         }
@@ -885,17 +861,17 @@ void SwTableShell::Execute(SfxRequest &rReq)
         case FN_TABLE_SET_ROW_HEIGHT:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-            DBG_ASSERT(pFact, "SwAbstractDialogFactory fail!");
+            OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
 
             VclAbstractDialog* pDlg = pFact->CreateVclAbstractDialog( GetView().GetWindow(), rSh, DLG_ROW_HEIGHT );
-            DBG_ASSERT(pDlg, "Dialogdiet fail!");
+            OSL_ENSURE(pDlg, "Dialogdiet fail!");
             pDlg->Execute();
             delete pDlg;
         }
         break;
         case FN_NUMBER_BULLETS:
         case FN_NUM_BULLET_ON:
-            ASSERT( !this, "Funktion darf zur Zeit nicht gerufen werden." );
+            OSL_ENSURE( !this, "function may not be called now." );
         break;
 
         case FN_TABLE_INSERT_COL:
@@ -1043,10 +1019,10 @@ void SwTableShell::Execute(SfxRequest &rReq)
             else
             {
                 SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-                DBG_ASSERT(pFact, "SwAbstractDialogFactory fail!");
+                OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
 
                 AbstractSplitTableDialog* pDlg = pFact->CreateSplitTblDialog( GetView().GetWindow(), rSh );
-                DBG_ASSERT(pDlg, "Dialogdiet fail!");
+                OSL_ENSURE(pDlg, "Dialogdiet fail!");
                 pDlg->Execute();
                 rReq.AppendItem( SfxUInt16Item( FN_PARAM_1, pDlg->GetSplitMode() ) );
                 delete pDlg;
@@ -1063,9 +1039,9 @@ void SwTableShell::Execute(SfxRequest &rReq)
             if( bPrev && bNext )
             {
                 SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-                DBG_ASSERT(pFact, "SwAbstractDialogFactory fail!");
+                OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
                 VclAbstractDialog* pDlg = pFact->CreateSwVclDialog( DLG_MERGE_TABLE, GetView().GetWindow(), bPrev );
-                DBG_ASSERT(pDlg, "dialogdiet pDlg fail!");
+                OSL_ENSURE(pDlg, "dialogdiet pDlg fail!");
                 if( RET_OK != pDlg->Execute())
                     bPrev = bNext = FALSE;
                 delete pDlg;
@@ -1236,15 +1212,12 @@ void SwTableShell::Execute(SfxRequest &rReq)
         break;
 
         default:
-            ASSERT( !this, "falscher Dispatcher" );
+            OSL_ENSURE( !this, "wrong Dispatcher" );
             return;
     }
     if(bCallDone)
         rReq.Done();
 }
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
 
 void SwTableShell::GetState(SfxItemSet &rSet)
 {
@@ -1329,9 +1302,9 @@ void SwTableShell::GetState(SfxItemSet &rSet)
             case FN_TABLE_VERT_BOTTOM:
             {
                 USHORT nAlign = rSh.GetBoxAlign();
-                BOOL bSet = nSlot == FN_TABLE_VERT_NONE && nAlign == text::VertOrientation::NONE||
-                            nSlot == FN_TABLE_VERT_CENTER && nAlign == text::VertOrientation::CENTER ||
-                            nSlot == FN_TABLE_VERT_BOTTOM && nAlign == text::VertOrientation::BOTTOM;
+                BOOL bSet = (nSlot == FN_TABLE_VERT_NONE && nAlign == text::VertOrientation::NONE) ||
+                            (nSlot == FN_TABLE_VERT_CENTER && nAlign == text::VertOrientation::CENTER) ||
+                            (nSlot == FN_TABLE_VERT_BOTTOM && nAlign == text::VertOrientation::BOTTOM);
                 rSet.Put(SfxBoolItem(nSlot, bSet));
             }
             break;
@@ -1341,9 +1314,9 @@ void SwTableShell::GetState(SfxItemSet &rSet)
             case FN_TABLE_MODE_VARIABLE	 :
                 {
                     TblChgMode nMode = rSh.GetTblChgMode();
-                    BOOL bSet = nSlot == FN_TABLE_MODE_FIX && nMode == TBLFIX_CHGABS ||
-                            nSlot == FN_TABLE_MODE_FIX_PROP && nMode == TBLFIX_CHGPROP ||
-                            nSlot == FN_TABLE_MODE_VARIABLE && nMode == TBLVAR_CHGABS;
+                    BOOL bSet = (nSlot == FN_TABLE_MODE_FIX && nMode == TBLFIX_CHGABS) ||
+                                (nSlot == FN_TABLE_MODE_FIX_PROP && nMode == TBLFIX_CHGPROP) ||
+                                (nSlot == FN_TABLE_MODE_VARIABLE && nMode == TBLVAR_CHGABS);
                     rSet.Put(SfxBoolItem(nSlot, bSet));
                 }
             break;
@@ -1427,10 +1400,6 @@ void SwTableShell::GetState(SfxItemSet &rSet)
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SwTableShell::SwTableShell(SwView &_rView) :
     SwBaseShell(_rView)
 {
@@ -1438,10 +1407,6 @@ SwTableShell::SwTableShell(SwView &_rView) :
     SetHelpId(SW_TABSHELL);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwTableShell::GetFrmBorderState(SfxItemSet &rSet)
 {
     SfxItemSet aCoreSet( GetPool(),
@@ -1453,10 +1418,6 @@ void SwTableShell::GetFrmBorderState(SfxItemSet &rSet)
     rSet.Put( aCoreSet );
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwTableShell::ExecTableStyle(SfxRequest& rReq)
 {
     SwWrtShell &rSh = GetShell();
@@ -1511,7 +1472,6 @@ void SwTableShell::ExecTableStyle(SfxRequest& rReq)
         }
 }
 
-
 void SwTableShell::GetLineStyleState(SfxItemSet &rSet)
 {
     SfxItemSet aCoreSet( GetPool(),
@@ -1579,7 +1539,7 @@ void SwTableShell::ExecNumberFormat(SfxRequest& rReq)
         break;
 
     default:
-        ASSERT(FALSE, falscher Dispatcher);
+        OSL_ENSURE(false, "wrong dispatcher");
         return;
     }
 
@@ -1595,3 +1555,4 @@ void SwTableShell::ExecNumberFormat(SfxRequest& rReq)
 
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
