@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -66,22 +67,15 @@
 
 #include <cmdid.h>
 #include <helpid.h>
-#ifndef _NAVIPI_HRC
 #include <navipi.hrc>
-#endif
-#ifndef _UTLUI_HRC
 #include <utlui.hrc>
-#endif
-#ifndef _COMCORE_HRC
 #include <comcore.hrc>
-#endif
 #include <globals.hrc>
 #include "swabstdlg.hxx"
 
 using namespace ::com::sun::star::uno;
 using ::rtl::OUString;
 
-
 // Kontextmenue fuer GlobalTree
 #define CTX_INSERT_ANY_INDEX 10
 //#define CTX_INSERT_CNTIDX   11
@@ -145,12 +139,6 @@ static const USHORT __FAR_DATA aHelpForMenu[] =
     HID_GLBLTREEUPD_ALL			//CTX_UPDATE_ALL
 };
 
-/************************************************************************/
-/*																		*/
-/************************************************************************/
-/* -----------------------------24.08.00 12:04--------------------------------
-
- ---------------------------------------------------------------------------*/
 class SwGlobalFrameListener_Impl : public SfxListener
 {
     BOOL bValid;
@@ -165,9 +153,7 @@ public:
 
     BOOL 				IsValid() const {return bValid;}
 };
-/* -----------------------------24.08.00 12:05--------------------------------
 
- ---------------------------------------------------------------------------*/
 void    SwGlobalFrameListener_Impl::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     if( rHint.ISA(SfxSimpleHint) &&
@@ -175,9 +161,6 @@ void    SwGlobalFrameListener_Impl::Notify( SfxBroadcaster& /*rBC*/, const SfxHi
         bValid = FALSE;
 }
 
-/*-----------------12.06.97 09:38-------------------
-
---------------------------------------------------*/
 SwGlobalTree::SwGlobalTree(Window* pParent, const ResId& rResId) :
 
     SvTreeListBox(pParent, rResId),
@@ -212,18 +195,12 @@ SwGlobalTree::SwGlobalTree(Window* pParent, const ResId& rResId) :
     EnableContextMenuHandling();
 }
 
-/*-----------------12.06.97 09:38-------------------
-
---------------------------------------------------*/
 SwGlobalTree::~SwGlobalTree()
 {
     delete pSwGlblDocContents;
     delete pDocInserter;
 }
 
-/*-----------------12.06.97 09:38-------------------
-
---------------------------------------------------*/
 sal_Int8 SwGlobalTree::ExecuteDrop( const ExecuteDropEvent& rEvt )
 {
     sal_Int8 nRet = DND_ACTION_NONE;
@@ -303,9 +280,7 @@ sal_Int8 SwGlobalTree::ExecuteDrop( const ExecuteDropEvent& rEvt )
     return nRet;
 
 }
-/*-----------------12.06.97 09:38-------------------
 
---------------------------------------------------*/
 sal_Int8 SwGlobalTree::AcceptDrop( const AcceptDropEvent& rEvt )
 {
     sal_Int8 nRet = rEvt.mnAction;
@@ -364,9 +339,7 @@ sal_Int8 SwGlobalTree::AcceptDrop( const AcceptDropEvent& rEvt )
     }
     return nRet;
 }
-/*-----------------12.06.97 09:38-------------------
 
---------------------------------------------------*/
 PopupMenu* SwGlobalTree::CreateContextMenu()
 {
     PopupMenu* pPop = 0;
@@ -427,9 +400,7 @@ PopupMenu* SwGlobalTree::CreateContextMenu()
     }
     return pPop;
 }
-/*-----------------16.06.97 10:41-------------------
 
---------------------------------------------------*/
 void SwGlobalTree::TbxMenuHdl(USHORT nTbxId, ToolBox* pBox)
 {
     USHORT nEnableFlags = GetEnableFlags();
@@ -469,9 +440,7 @@ void SwGlobalTree::TbxMenuHdl(USHORT nTbxId, ToolBox* pBox)
         pBox->Invalidate();
     }
 }
-/*-----------------16.06.97 11:02-------------------
 
---------------------------------------------------*/
 USHORT	SwGlobalTree::GetEnableFlags() const
 {
     SvLBoxEntry* pEntry = FirstSelected();
@@ -502,9 +471,6 @@ USHORT	SwGlobalTree::GetEnableFlags() const
     return nRet;
 }
 
-/*-----------------12.06.97 09:38-------------------
-
---------------------------------------------------*/
 void	 SwGlobalTree::RequestHelp( const HelpEvent& rHEvt )
 {
     BOOL bParent = TRUE;
@@ -552,9 +518,7 @@ void	 SwGlobalTree::RequestHelp( const HelpEvent& rHEvt )
     if(bParent)
         SvTreeListBox::RequestHelp(rHEvt);
 }
-/*-----------------16.06.97 16:15-------------------
 
---------------------------------------------------*/
 void	 SwGlobalTree::SelectHdl()
 {
 
@@ -573,17 +537,12 @@ void	 SwGlobalTree::SelectHdl()
                     nSelCount == 1 && nAbsPos < ((USHORT)GetEntryCount()) - 1 && !bReadonly);
 
 }
-/*-----------------16.06.97 16:15-------------------
 
---------------------------------------------------*/
 void	 SwGlobalTree::DeselectHdl()
 {
     SelectHdl();
 }
 
-/*-----------------17.06.97 13:11-------------------
-
---------------------------------------------------*/
 DragDropMode SwGlobalTree::NotifyStartDrag( TransferDataContainer& ,
                                                 SvLBoxEntry* pEntry )
 {
@@ -592,17 +551,11 @@ DragDropMode SwGlobalTree::NotifyStartDrag( TransferDataContainer& ,
     return SV_DRAGDROP_CTRL_MOVE;
 }
 
-/*-----------------21.06.97 12:44-------------------
-
---------------------------------------------------*/
 long     SwGlobalTree::GetTabPos( SvLBoxEntry*, SvLBoxTab* pTab)
 {
     return pTab->GetPos() - GLBL_TABPOS_SUB;
 }
 
-/*-----------------12.06.97 09:38-------------------
-
---------------------------------------------------*/
 BOOL     SwGlobalTree::NotifyMoving(   SvLBoxEntry*  pTarget,
                                         SvLBoxEntry*  pSource,
                                         SvLBoxEntry*&,
@@ -619,9 +572,7 @@ BOOL     SwGlobalTree::NotifyMoving(   SvLBoxEntry*  pTarget,
         Display();
     return FALSE;
 }
-/*-----------------12.06.97 09:39-------------------
 
---------------------------------------------------*/
 BOOL     SwGlobalTree::NotifyCopying(  SvLBoxEntry*  /*pTarget*/,
                                         SvLBoxEntry*  /*pEntry*/,
                                         SvLBoxEntry*& /*rpNewParent*/,
@@ -630,24 +581,18 @@ BOOL     SwGlobalTree::NotifyCopying(  SvLBoxEntry*  /*pTarget*/,
 {
     return FALSE;
 }
-/*-----------------12.06.97 09:39-------------------
 
---------------------------------------------------*/
 BOOL SwGlobalTree::NotifyAcceptDrop( SvLBoxEntry* pEntry)
 {
     return pEntry != 0;
 }
-/*-----------------12.06.97 09:39-------------------
 
---------------------------------------------------*/
 void SwGlobalTree::StartDrag( sal_Int8 nAction, const Point& rPt )
 {
     if( 1 == GetSelectionCount() )
         SvTreeListBox::StartDrag( nAction, rPt );
 }
-/*-----------------12.06.97 09:39-------------------
 
---------------------------------------------------*/
 void SwGlobalTree::DragFinished( sal_Int8 nAction )
 {
     SvTreeListBox::DragFinished( nAction );
@@ -668,9 +613,6 @@ void  SwGlobalTree::MouseButtonDown( const MouseEvent& rMEvt )
         SvTreeListBox::MouseButtonDown( rMEvt );
 }
 
-/*-----------------12.06.97 13:08-------------------
-
---------------------------------------------------*/
 void     SwGlobalTree::GetFocus()
 {
     if(Update( FALSE ))
@@ -678,9 +620,6 @@ void     SwGlobalTree::GetFocus()
     SvTreeListBox::GetFocus();
 }
 
-/*-----------------12.06.97 12:34-------------------
-
---------------------------------------------------*/
 void     SwGlobalTree::KeyInput(const KeyEvent& rKEvt)
 {
     const KeyCode aCode = rKEvt.GetKeyCode();
@@ -698,17 +637,12 @@ void     SwGlobalTree::KeyInput(const KeyEvent& rKEvt)
         SvTreeListBox::KeyInput(rKEvt);
 }
 
-/*-----------------17.06.97 11:59-------------------
-
---------------------------------------------------*/
 void SwGlobalTree::Clear()
 {
     pEmphasisEntry = 0;
     SvTreeListBox::Clear();
 }
-/*-----------------12.06.97 12:38-------------------
 
---------------------------------------------------*/
 void 	SwGlobalTree::Display(BOOL bOnlyUpdateUserData)
 {
     if(!bIsImageListInitialized)
@@ -795,9 +729,6 @@ void 	SwGlobalTree::Display(BOOL bOnlyUpdateUserData)
     }
 }
 
-/*-----------------13.06.97 10:32-------------------
-
---------------------------------------------------*/
 void SwGlobalTree::InsertRegion( const SwGlblDocContent* pCont, const String* pFileName )
 {
     Sequence< OUString > aFileNames;
@@ -820,9 +751,6 @@ void SwGlobalTree::InsertRegion( const SwGlblDocContent* pCont, const String* pF
     }
 }
 
-/*-----------------18.06.97 12:42-------------------
-
---------------------------------------------------*/
 void 	SwGlobalTree::EditContent(const SwGlblDocContent* pCont )
 {
     USHORT nSlot = 0;
@@ -857,17 +785,12 @@ void 	SwGlobalTree::EditContent(const SwGlblDocContent* pCont )
     }
 }
 
-/*-----------------13.06.97 14:22-------------------
-
---------------------------------------------------*/
 IMPL_LINK( SwGlobalTree, PopupHdl, Menu* , pMenu)
 {
     ExcecuteContextMenuAction( pMenu->GetCurItemId());
     return TRUE;
 }
-/* -----------------26.08.2003 11:57-----------------
 
- --------------------------------------------------*/
 void    SwGlobalTree::ExcecuteContextMenuAction( USHORT nSelectedPopupEntry )
 //IMPL_LINK( SwGlobalTree, PopupHdl, Menu* , pMenu)
 {
@@ -928,13 +851,13 @@ void    SwGlobalTree::ExcecuteContextMenuAction( USHORT nSelectedPopupEntry )
         break;
         case CTX_EDIT:
         {
-            DBG_ASSERT(pCont, "Edit ohne Entry ? " );
+            OSL_ENSURE(pCont, "edit without entry ? " );
             EditContent(pCont);
         }
         break;
         case CTX_EDIT_LINK:
         {
-            DBG_ASSERT(pCont, "Edit ohne Entry ? " );
+            OSL_ENSURE(pCont, "edit without entry ? " );
             SfxStringItem aName(FN_EDIT_REGION,
                     pCont->GetSection()->GetSectionName());
             rDispatch.Execute(FN_EDIT_REGION, SFX_CALLMODE_ASYNCHRON, &aName, 0L);
@@ -981,14 +904,14 @@ void    SwGlobalTree::ExcecuteContextMenuAction( USHORT nSelectedPopupEntry )
                             0);
 
                 SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-                DBG_ASSERT(pFact, "Dialogdiet fail!");
+                OSL_ENSURE(pFact, "Dialogdiet fail!");
                 AbstractMultiTOXTabDialog* pDlg = pFact->CreateMultiTOXTabDialog( DLG_MULTI_TOX,
                                                         this, aSet,
                                                         *pActiveShell,
                                                         0,
                                                         USHRT_MAX,
                                                         TRUE);
-                DBG_ASSERT(pDlg, "Dialogdiet fail!");
+                OSL_ENSURE(pDlg, "Dialogdiet fail!");
                 if(RET_OK == pDlg->Execute())
                 {
                     SwTOXDescription&  rDesc = pDlg->GetTOXDescription(
@@ -1104,9 +1027,6 @@ void    SwGlobalTree::ExcecuteContextMenuAction( USHORT nSelectedPopupEntry )
 //  return TRUE;
 }
 
-/*-----------------16.06.97 07:57-------------------
-
---------------------------------------------------*/
 IMPL_LINK( SwGlobalTree, Timeout, Timer*, EMPTYARG )
 {
     if(!HasFocus() && Update( FALSE ))
@@ -1114,9 +1034,6 @@ IMPL_LINK( SwGlobalTree, Timeout, Timer*, EMPTYARG )
     return 0;
 }
 
-/*-----------------13.06.97 16:56-------------------
-
---------------------------------------------------*/
 void SwGlobalTree::GotoContent(const SwGlblDocContent* pCont)
 {
     pActiveShell->EnterStdMode();
@@ -1138,29 +1055,23 @@ void SwGlobalTree::GotoContent(const SwGlblDocContent* pCont)
     }
 
 }
-/*-----------------16.06.97 07:42-------------------
 
---------------------------------------------------*/
 void	SwGlobalTree::ShowTree()
 {
     aUpdateTimer.Start();
     SvTreeListBox::Show();
 }
-/*-----------------16.06.97 07:42-------------------
 
---------------------------------------------------*/
 void	SwGlobalTree::HideTree()
 {
     aUpdateTimer.Stop();
     SvTreeListBox::Hide();
 }
-/*-----------------18.06.97 10:02-------------------
 
---------------------------------------------------*/
 void 	SwGlobalTree::ExecCommand(USHORT nCmd)
 {
     SvLBoxEntry* pEntry = FirstSelected();
-    DBG_ASSERT(pEntry, "gleich knallt's");
+    OSL_ENSURE(pEntry, "gleich knallt's");
     if(FN_GLOBAL_EDIT == nCmd)
     {
         const SwGlblDocContent* pCont = (const SwGlblDocContent*)
@@ -1199,9 +1110,6 @@ void 	SwGlobalTree::ExecCommand(USHORT nCmd)
     }
 }
 
-/*-----------------16.06.97 07:43-------------------
-
---------------------------------------------------*/
 BOOL  	SwGlobalTree::Update(BOOL bHard)
 {
     SwView* pActView = GetParentWindow()->GetCreateView();
@@ -1241,11 +1149,20 @@ BOOL  	SwGlobalTree::Update(BOOL bHard)
                     GlobalDocContentType eType = pLeft->GetType();
                     SvLBoxEntry* pEntry = GetEntry(i);
                     String sTemp = GetEntryText(pEntry);
-                    if(eType != pRight->GetType() ||
-                        eType == GLBLDOC_SECTION &&
-                            (pLeft->GetSection()->GetSectionName() != sTemp) ||
-                        eType == GLBLDOC_TOXBASE && pLeft->GetTOX()->GetTitle() != sTemp)
-                            bCopy = bRet = TRUE;
+                    if (
+                         eType != pRight->GetType() ||
+                         (
+                           eType == GLBLDOC_SECTION &&
+                           pLeft->GetSection()->GetSectionName() != sTemp
+                         ) ||
+                         (
+                           eType == GLBLDOC_TOXBASE &&
+                           pLeft->GetTOX()->GetTitle() != sTemp
+                         )
+                       )
+                    {
+                        bCopy = bRet = TRUE;
+                    }
                 }
             }
             if(bCopy || bHard)
@@ -1275,9 +1192,6 @@ BOOL  	SwGlobalTree::Update(BOOL bHard)
     return bRet;
 }
 
-/*-----------------25.06.97 16:20-------------------
-
---------------------------------------------------*/
 void SwGlobalTree::OpenDoc(const SwGlblDocContent* pCont)
 {
     String sFileName(pCont->GetSection()->GetLinkFileName().GetToken(0,
@@ -1311,9 +1225,6 @@ void SwGlobalTree::OpenDoc(const SwGlblDocContent* pCont)
     }
 }
 
-/*-----------------25.06.97 16:08-------------------
-
---------------------------------------------------*/
 IMPL_LINK( 	SwGlobalTree, DoubleClickHdl, SwGlobalTree *, EMPTYARG )
 {
     SvLBoxEntry* pEntry = GetCurEntry();
@@ -1328,9 +1239,6 @@ IMPL_LINK( 	SwGlobalTree, DoubleClickHdl, SwGlobalTree *, EMPTYARG )
     return 0;
 }
 
-/*-----------------07.10.97 08:09-------------------
-
---------------------------------------------------*/
 IMPL_STATIC_LINK_NOINSTANCE(SwGlobalTree, ShowFrameHdl, SwGlobalTree*, EMPTYARG)
 {
     if(SwGlobalTree::GetShowShell())
@@ -1338,9 +1246,7 @@ IMPL_STATIC_LINK_NOINSTANCE(SwGlobalTree, ShowFrameHdl, SwGlobalTree*, EMPTYARG)
     SwGlobalTree::SetShowShell(0);
     return 0;
 }
-/* -----------------04.11.98 10:43-------------------
- *
- * --------------------------------------------------*/
+
 void SwGlobalTree::InitEntry(SvLBoxEntry* pEntry,
         const XubString& rStr ,const Image& rImg1,const Image& rImg2,
         SvLBoxButtonKind eButtonKind)
@@ -1351,9 +1257,6 @@ void SwGlobalTree::InitEntry(SvLBoxEntry* pEntry,
     SwLBoxString* pStr = new SwLBoxString( pEntry, 0, pCol->GetText() );
     pEntry->ReplaceItem( pStr, nColToHilite );
 }
-/* -----------------04.11.98 10:39-------------------
- *
- * --------------------------------------------------*/
 
 void SwLBoxString::Paint( const Point& rPos, SvLBox& rDev, USHORT nFlags,
     SvLBoxEntry* pEntry )
@@ -1374,9 +1277,7 @@ void SwLBoxString::Paint( const Point& rPos, SvLBox& rDev, USHORT nFlags,
     else
         SvLBoxString::Paint( rPos, rDev, nFlags, pEntry);
 }
-/* -----------------------------06.05.2002 10:20------------------------------
 
- ---------------------------------------------------------------------------*/
 void    SwGlobalTree::DataChanged( const DataChangedEvent& rDCEvt )
 {
     if ( (rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
@@ -1426,7 +1327,7 @@ void SwGlobalTree::InsertRegion( const SwGlblDocContent* _pContent, const Sequen
             //update the global document content after each inserted document
             rSh.GetGlobalDocContent(aTempContents);
             SwGlblDocContent* pAnchorContent = 0;
-            DBG_ASSERT(aTempContents.Count() > (nAnchorContent + nFile), "invalid anchor content -> last insertion failed");
+            OSL_ENSURE(aTempContents.Count() > (nAnchorContent + nFile), "invalid anchor content -> last insertion failed");
             if ( aTempContents.Count() > (nAnchorContent + nFile) )
                 pAnchorContent = aTempContents.GetObject(nAnchorContent + (USHORT)nFile);
             else
@@ -1512,3 +1413,4 @@ IMPL_LINK( SwGlobalTree, DialogClosedHdl, sfx2::FileDialogHelper*, _pFileDlg )
     return 0;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
