@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -42,9 +43,7 @@
 #include <svx/svdview.hxx>
 #include <sot/factory.hxx>
 #include <svl/itemiter.hxx>
-#ifndef _SOUND_HXX //autogen
 #include <vcl/sound.hxx>
-#endif
 #include <tools/bigint.hxx>
 #include <sot/storage.hxx>
 #include <svtools/insdlg.hxx>
@@ -67,21 +66,13 @@
 #include <svx/fontworkbar.hxx>
 #include <fmtftn.hxx>
 #include <fmtpdsc.hxx>
-#ifndef _WDOCSH_HXX
 #include <wdocsh.hxx>
-#endif
-#ifndef _BASESH_HXX
 #include <basesh.hxx>
-#endif
 #include <swmodule.hxx>
 #include <wrtsh.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <uitool.hxx>
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
 #include <pagedesc.hxx>
 #include <frmmgr.hxx>
 #include <shellio.hxx>
@@ -89,9 +80,7 @@
 #include <swundo.hxx>  // fuer Undo-Ids
 #include <swcli.hxx>
 #include <poolfmt.hxx>
-#ifndef _WVIEW_HXX
 #include <wview.hxx>
-#endif
 #include <edtwin.hxx>
 #include <fmtcol.hxx>
 #include <swtable.hxx>
@@ -100,15 +89,12 @@
 #include <swdtflvr.hxx>
 #include <crsskip.hxx>
 #include <doc.hxx>
-#ifndef _WRTSH_HRC
 #include <wrtsh.hrc>
-#endif
 #include <SwStyleNameMapper.hxx>
 #include <sfx2/request.hxx>
 #include <paratr.hxx>
 #include <ndtxt.hxx>
 #include <editeng/acorrcfg.hxx>
-//#include <svx/acorrcfg.hxx>
 #include <IMark.hxx>
 
 // -> #111827#
@@ -577,7 +563,7 @@ BOOL SwWrtShell::InsertOleObject( const svt::EmbeddedObjectRef& xRef, SwFlyFrmFm
                 {
                     try
                     {
-                        xSet->setPropertyValue( ::rtl::OUString::createFromAscii("Formula"), uno::makeAny( ::rtl::OUString( aMathData ) ) );
+                        xSet->setPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Formula")), uno::makeAny( ::rtl::OUString( aMathData ) ) );
                         bActivate = FALSE;
                     }
                     catch ( uno::Exception& )
@@ -647,7 +633,7 @@ void SwWrtShell::LaunchOLEObj( long nVerb )
          !GetView().GetViewFrame()->GetFrame().IsInPlace() )
     {
         svt::EmbeddedObjectRef& xRef = GetOLEObject();
-        ASSERT( xRef.is(), "OLE not found" );
+        OSL_ENSURE( xRef.is(), "OLE not found" );
         SfxInPlaceClient* pCli=0;
 
         pCli = GetView().FindIPClient( xRef.GetObject(), &GetView().GetEditWin() );
@@ -693,7 +679,7 @@ void SwWrtShell::CalcAndSetScale( svt::EmbeddedObjectRef& xObj,
 {
     //Einstellen der Skalierung am Client. Diese ergibt sich aus der Differenz
     //zwischen der VisArea des Objektes und der ObjArea.
-    ASSERT( xObj.is(), "ObjectRef not  valid" );
+    OSL_ENSURE( xObj.is(), "ObjectRef not  valid" );
 
     sal_Int64 nAspect = xObj.GetViewAspect();
     if ( nAspect == embed::Aspects::MSOLE_ICON )
@@ -792,13 +778,13 @@ void SwWrtShell::CalcAndSetScale( svt::EmbeddedObjectRef& xObj,
     }
     catch( embed::NoVisualAreaSizeException& )
     {
-        DBG_ERROR( "Can't get visual area size!\n" );
+        OSL_ENSURE(false, "Can't get visual area size!\n" );
         // the scaling will not be done
     }
     catch( uno::Exception& )
     {
         // TODO/LATER: handle the error
-        DBG_ERROR( "Can't get visual area size!\n" );
+        OSL_ENSURE(false, "Can't get visual area size!\n" );
         return;
     }
 
@@ -1144,9 +1130,9 @@ void SwWrtShell::NumOrBulletOn(BOOL bNum)
                     // check, if numbering of the outline level of the pararaph
                     // style is active. If not, activate this outline level.
                     nActivateOutlineLvl = pColl->GetAssignedOutlineStyleLevel();
-                    ASSERT( pColl->IsAssignedToListLevelOfOutlineStyle(),	//<-end,zhaojianwei
+                    OSL_ENSURE( pColl->IsAssignedToListLevelOfOutlineStyle(),
                             "<SwWrtShell::NumOrBulletOn(..)> - paragraph style with outline rule, but no outline level" );
-                    if ( pColl->IsAssignedToListLevelOfOutlineStyle() &&		//<-end,zhaojianwei
+                    if ( pColl->IsAssignedToListLevelOfOutlineStyle() &&
                          pCollRule->Get( static_cast<USHORT>(nActivateOutlineLvl) ).GetNumberingType()
                             == SVX_NUM_NUMBER_NONE )
                     {
@@ -1192,10 +1178,10 @@ void SwWrtShell::NumOrBulletOn(BOOL bNum)
             {
                 // check, if numbering of the outline level of the pararaph
                 // style is active. If not, activate this outline level.
-                nActivateOutlineLvl = pColl->GetAssignedOutlineStyleLevel();//#outline level,zhaojianwei
-                ASSERT( pColl->IsAssignedToListLevelOfOutlineStyle(),//#outline level,zhaojianwei
+                nActivateOutlineLvl = pColl->GetAssignedOutlineStyleLevel();
+                OSL_ENSURE( pColl->IsAssignedToListLevelOfOutlineStyle(),
                         "<SwWrtShell::NumOrBulletOn(..)> - paragraph style with outline rule, but no outline level" );
-                if ( pColl->IsAssignedToListLevelOfOutlineStyle() &&//#outline level,zhaojianwei
+                if ( pColl->IsAssignedToListLevelOfOutlineStyle() &&
                      pCollRule->Get( static_cast<USHORT>(nActivateOutlineLvl) ).GetNumberingType()
                         == SVX_NUM_NUMBER_NONE )
                 {
@@ -1789,6 +1775,12 @@ SwWrtShell::SwWrtShell( SwDoc& rDoc, Window *_pWin, SwView &rShell,
     SET_CURR_SHELL( this );
     SetSfxViewShell( (SfxViewShell *)&rShell );
     SetFlyMacroLnk( LINK(this, SwWrtShell, ExecFlyMac) );
+
+    // place the cursor on the first field...
+    IFieldmark *pBM = NULL;
+    if ( IsFormProtected() && ( pBM = GetFieldmarkAfter( ) ) !=NULL ) {
+        GotoFieldmark(pBM);
+    }
 }
 
 /*
@@ -1871,3 +1863,5 @@ String SwWrtShell::GetSelDescr() const
 
     return aResult;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
